import axios from 'axios';
import config from './config';
import ak from './ak';
import { ua } from './ua'
import session from '../session';


var axiosInstance = axios.create({
    baseURL: config.http.gwURL,
    timeout: config.http.timeout,
    withCredentials: false
});

var axiosInstanceFile = axios.create({
    baseURL: config.file.baseURL,
    timeout: config.file.timeout,
    withCredentials: false
});


axiosInstance.interceptors.response.use(
  function (response) {
    session.sys.loadcnt--
    return response;
},
  function (error) {

    session.sys.loadcnt--
    if (error.message === 'Network Error') {
      ak.msg.alert('网络不可用，请重试！')
      return Promise.reject(error)
    }
    if (error.message.indexOf('timeout') > -1) {
      ak.msg.alert('网络超时，请重试！')
      return Promise.reject(error)
    }
    if (!error.response) {
      ak.msg.alert(error.message)
      return Promise.reject(error)
    }

    if (error.response.status === 401) {

      var url = config.sso.baseURL + "/GETST?service=" + encodeURIComponent(config.sso.baseURL2+"/SSO-JTL.html?service=" + encodeURIComponent(location.href))
      url = url + "&loginUrl=" + encodeURIComponent(config.sso.loginUrl + "?service=" + encodeURIComponent(location.href))
      location.href = url

      return Promise.reject(error);

    }else if (error.response.status === 200) {

      return Promise.resolve(error.response);

    }else{

      ak.msg.alert('服务调用错误，请重试')
      return Promise.reject(error)
    }


});


axiosInstance.interceptors.request.use(
    function(config2) {

      session.sys.loadcnt++

      var jtlu = ak.utils.getUrlKey("jtl",window.location.href)
      if(jtlu){

        ak.http.setCookie("jtl",jtlu)
        var url2 = window.location.href
        url2 = url2.replace('jtl=' + jtlu,'')
        url2 = url2.replace('&jtl=' + jtlu,'')

        window.location.href = url2
        return config2;

      }

      var haveBasic = !ak.utils.isEmpty(config2.headers.Authorization) && config2.headers.Authorization.startWith('Basic ')
      if(haveBasic){
        var jtl = ak.http.getCookie("jtl")
        if(!jtl){

          var url = config.sso.baseURL + "/GETST?service=" + encodeURIComponent(config.sso.baseURL2+"/SSO-JTL.html?service=" + encodeURIComponent(location.href))
          url = url + "&loginUrl=" + encodeURIComponent(config.sso.loginUrl + "?service=" + encodeURIComponent(location.href))
          location.href = url

        }
      }

      return config2;
    },
    function(error) {

        session.sys.loadcnt--
        return Promise.reject(error);
    }
);


axiosInstanceFile.interceptors.request.use(
    function(config) {
        session.sys.loadcnt++
        return config;
    },
    function(error) {
        session.sys.loadcnt--
        return Promise.reject(error);
    }
);


axiosInstanceFile.interceptors.response.use(
  function (response) {
    session.sys.loadcnt--
    return response;
  },
  function (error) {

    session.sys.loadcnt--
    if (error.message === 'Network Error') {
      ak.msg.alert('网络不可用，请重试！')
      return Promise.reject(error)
    }
    if (error.message.indexOf('timeout') > -1) {
      ak.msg.alert('网络超时，请重试！')
      return Promise.reject(error)
    }
    if (!error.response) {
      ak.msg.alert(error.message)
      return Promise.reject(error)
    }

    if (error.response.status === 401) {

      var url = config.sso.baseURL + "/GETST?service=" + encodeURIComponent(config.sso.baseURL2+"/SSO-JTL.html?service=" + encodeURIComponent(location.href))
      url = url + "&loginUrl=" + encodeURIComponent(config.sso.loginUrl + "?service=" + encodeURIComponent(location.href))
      location.href = url

      return Promise.reject(error);

    }else if (error.response.status === 200) {

      return Promise.resolve(error.response);

    }else{

      ak.msg.alert('服务调用错误，请重试')
      return Promise.reject(error)
    }


  });


var http = {

  getHeader :function(needAuth,fillBearer) {

      let deviceInfo = 'NULL'
      let deviceType = 'PC'
      let deviceOS = 'NULL'
      let isp = 'NULL'
      let deviceId = 'NULL'
      let appInfo = 'NULL'
      let userId = ''
      let IP = 'NULL'

      let header = {
        'Content-Type': 'application/json',
        'Accept-Device': deviceInfo, // 设备名称及型号
        'Accept-DeviceOS': deviceOS, // 设备系统名称及型号
        'Accept-Location': 'NULL', // 设置位置
        'Accept-ISP': isp, // 网络
        'Accept-StartTime': 20200518212929, // 设备启动时间，格式YYYYMMDDHI24MISS
        'Accept-TimeZone': '28800000', // 时区偏移
        'Accept-Attr1': deviceId, // 设备唯一号
        'Accept-Attr2': deviceType, // 终端类型（枚举：PAD，PC，PHONE其中一种）
        'Accept-Attr3': 'zh_CN', // 访问的语言Locale（可空，不传NULL），格式为如zh_CN这种
        'Accept-Attr4': appInfo, // app信息，格式为appid加版本号，如：com.hasl.isp.native--1.1（PC传NULL ）
        'Accept-Attr6': userId, // 前台登陆的用户名（没有登陆传NULL）
        'Real-Ip': IP // 客户端IP地址
      }

      if(needAuth){

        if(fillBearer && ak.utils.isEmpty(ak.http.getCookie("jtl"))){
          header['Authorization'] = 'Bearer ' + SSOToken.getToken(config.auth.userId, config.auth.privatKey, 60 * 10)
        }else{
          header['Authorization'] = 'Basic ' + ak.http.getCookie("jtl")
        }

      }else if(fillBearer){
        header['Authorization'] = 'Bearer ' + SSOToken.getToken(config.auth.userId, config.auth.privatKey, 60 * 10)
      }

      return header

    },

    getHeaderForUpload :function(needAuth,fillBearer) {

      let header = this.getHeader(needAuth,fillBearer)
      delete header['Content-Type']
      return header

    },

    get: function(resource,params) {

      let url = resource.startWith('http') ? resource : (config.http.gwURL + resource)

      return axiosInstance
                  .get(url, { params: params,
                    timeout: config.http.timeout })
                  .then(function(res) {
                    resolve(res.data)
                  })
                  .catch(function(err) {

                  });

    },

    post: function(resource,params,needAuth = false,fillBearer = false, reject = true) {

      let url = resource.startWith('http') ? resource : (config.http.gwURL + resource)

      let pro = axiosInstance
              .post(url, JSON.stringify(params),{
                  headers: this.getHeader(needAuth,fillBearer),
                  timeout: config.http.timeout
              })
              .then(function(res) {

                let data = res.data
                if(Object.prototype.toString.call(data) == "[object String]"){
                  data = JSON.parse(data)
                }
                
                if(data.result.isSuccess){
                  if(!ak.utils.isEmpty(data.result.message)){
                    return new Promise(function(resolve, reject) {
                      ak.msg.alert(data.result.message,()=>{
                        resolve(data.data)
                      })
                    })
                  }else{
                    return Promise.resolve(data.data)
                  }

                }else{

                  if(data.result.errorCode == 'E401' || data.result.errorCode == 'E403'){

                    var url = config.sso.baseURL + "/GETST?service=" + encodeURIComponent(config.sso.baseURL2+"/SSO-JTL.html?service=" + encodeURIComponent(location.href))
                    url = url + "&loginUrl=" + encodeURIComponent(config.sso.loginUrl + "?service=" + encodeURIComponent(location.href))
                    location.href = url

                    return Promise.reject(res)
                  }

                  var errorm = ''
                  for (let err2 = 0; err2 < data.result.errors.length; err2++) {
                    errorm += data.result.errors[err2].error + '\r\n'
                  }
            
                  if(errorm != ''){
                    return new Promise(function(resolve, reject) {
                      ak.msg.alert(errorm,()=>{
                        reject(res)
                      })
                    })
                  }
                  else{
                    return new Promise(function(resolve, reject) {
                      ak.msg.alert(data.result.error,()=>{
                        reject(res)
                      })
                    })
                  }
                }
              })

      if (reject) {
        pro.catch(function() {
          return Promise.reject()
        })
      }

      return pro

    },

    uploadFile: function(opts,needAuth = false,fillBearer = false, reject = true) {

        let param = new FormData();
        param.append("file", opts.file);
        param.append("name", opts.name);
        param.append("domain", opts.domain);
        param.append("buz", opts.buz);
        param.append("buzId", opts.buzId);
        param.append("expired", opts.expired);
        param.append("actions", opts.actions);

        console.log(param.get("file"));

        let pro = axiosInstanceFile
                .post(config.file.baseURL + '/file/v1/hasl/fileAdmin/fileAdmin/upload', param, {
                    headers: this.getHeaderForUpload(needAuth,fillBearer),
                    timeout: config.file.timeout,
                    onUploadProgress: e => {
                        var completeProgress = ((e.loaded / e.total * 100) | 0) + "%";
                        console.log(completeProgress);
                    }
                })
                .then(function(res) {

                  let data = res.data
                  if(Object.prototype.toString.call(data) == "[object String]"){
                    data = JSON.parse(data)
                  }

                  if(data.result.isSuccess){
                    if(!ak.utils.isEmpty(data.result.message)){
                      return new Promise(function(resolve, reject) {
                        ak.msg.alert(data.result.message,()=>{
                          resolve(data.data)
                        })
                      })
                    }else{
                      return Promise.resolve(data.data)
                    }

                  }else{
                    return new Promise(function(resolve, reject) {
                      ak.msg.alert(data.result.error,()=>{
                        reject(res)
                      })
                    })
                  }
                })

        if (reject) {
          pro.catch(function() {
            return Promise.reject()
          })
        }

        return pro

    }
};

export default http;
